﻿using System;
using System.Drawing;
using System.Xml.Serialization;
using Experior.Core.Assemblies;
using Experior.Core.Motors;
using Microsoft.DirectX;

namespace Experior.Catalog.Assemblies
{
    public class MyConveyor : Assembly
    {
        #region Constructors

        Core.Motors.Pneumatic pneumatic;

        public MyConveyor(MyConveyorInfo info)
            : base(info)
        {

            Core.Parts.Mesh conveyor = (Core.Parts.Mesh)Add(new Core.Parts.Mesh(Common.Meshes.Get("Conveyor")));
            Core.Parts.Mesh transfer = (Core.Parts.Mesh)Add(new Core.Parts.Mesh(Common.Meshes.Get("Transfer")));

            transfer.LocalPosition = new Vector3(0, 0.11f, -1.08f);

            pneumatic = new Pneumatic();
            pneumatic.Add(transfer);
            pneumatic.Name = "Lifting";
            pneumatic.Direction = new Vector3(0, 50f / 1000f, 0);

            Add(pneumatic);
        }

        public override void Activate()
        {
            pneumatic.Eject();
        }

        public override void DeActivate()
        {
            pneumatic.Inject();
        }

        public override void Step(float deltatime)
        {
            base.Step(deltatime);
            pneumatic.Step(deltatime);
        }

        #endregion

        #region Properties

        public override string Category
        {
            get { return "Conveyors"; }
        }

        public override Image Image
        {
            get { return Common.Icons.Get("MyConveyor"); }
        }

        #endregion
    }

    [Serializable]
    [XmlInclude(typeof(MyConveyorInfo))]
    public class MyConveyorInfo : Experior.Core.Assemblies.AssemblyInfo
    {

    }
}